$er = 0;
open F, "./test_int_set -quick 2>&1 |" or die;
while (<F>) {
  # print $_;
    if ($_ =~ /error has been detected/) {
    $er = 1;
    print "=============================================================\n";
    print $_, <F>;
  }

}
close(F); if ($?) { exit(1); }
if ($er == 1) { exit(1); }
